@@ -1412,10 +1412,13 @@ NV_STATUS uvm8_test_get_page_thrashing_policy(UVM_TEST_GET_PAGE_THRASHING_POLICY
 
     va_space_thrashing = va_space_thrashing_info_get(va_space);
 
-    if (va_space_thrashing->params.enable)
+    if (va_space_thrashing->params.enable) {
         params->policy = UVM_TEST_PAGE_THRASHING_POLICY_ENABLE;
-    else
+        params->nap_ns = va_space_thrashing->params.nap_ns;
+    }
+    else {
         params->policy = UVM_TEST_PAGE_THRASHING_POLICY_DISABLE;
+    }
 
     uvm_va_space_up_read(va_space);
 
